<?php

class WPshiftApi
{
    private static $api_base_url = 'https://app.wpshift.io/api/v1/';

    public static function init() {

    }

    public static function get_servers( $api_key ) {
        $response = wp_remote_get( self::$api_base_url . 'server/all', [
            'headers' => [
                'Authorization' => 'Bearer ' . $api_key,
            ],
        ]);

        if ( is_wp_error( $response ) ) {
            foreach($response->errors as $error){
                echo('<div class="notice notice-error">'.$error[0].'</div>');
            }
        }

        $body = json_decode(wp_remote_retrieve_body($response), true);
        if(isset($body['error'])){
            echo('<div class="notice notice-error">'.$body['error'].'</div>');
        }
        return $body;
    }

    public static function get_domains( $api_key ) {
        $response = wp_remote_get( self::$api_base_url . 'domains/all', [
            'headers' => [
                'Authorization' => 'Bearer ' . $api_key,
            ],
        ]);

        if ( is_wp_error( $response ) ) {
            foreach($response->errors as $error){
                echo('<div class="notice notice-error">'.$error[0].'</div>');
            }
        }

        $body = json_decode(wp_remote_retrieve_body($response), true);
        if(isset($body['error'])){
            echo('<div class="notice notice-error">'.$body['error'].'</div>');
        }
        return $body;
    }

    public static function check_sub_domain( $api_key, $sub_domain ) {
        $response = wp_remote_get( self::$api_base_url . 'domains/check-subdomain', [
            'headers' => [
                'Authorization' => 'Bearer ' . $api_key,
            ],
            'body' => [
                'sub_domain' => $sub_domain
            ],
        ]);

        if ( is_wp_error( $response ) ) {
            foreach($response->errors as $error){
                echo('<div class="notice notice-error">'.$error[0].'</div>');
            }
        }

        $body = json_decode(wp_remote_retrieve_body($response), true);
        if(isset($body['error'])){
            echo('<div class="notice notice-error">'.$body['error'].'</div>');
        }
        return $body;
    }

    public static function create_site( string $api_key, int $server_id, string $title, string $domain, string $domain_type, string $backup_file) {
        $response = wp_remote_post( self::$api_base_url . 'server/create-site', [
            'headers' => [
                'Authorization' => 'Bearer ' . $api_key,
            ],
            'body' => [
                'server_id' => $server_id,
                'title' => $title,
                'domain' => $domain,
                'domain_type' => $domain_type,
                'migration_file' => $backup_file,
                'migration_host' => get_option('siteurl')
            ],
        ]);

        print_r($response);

        if ( is_wp_error( $response ) ) {
            foreach($response->errors as $error){
                echo('<div class="notice notice-error">'.$error[0].'</div>');
            }
        }

        $body = json_decode(wp_remote_retrieve_body($response), true);
        if(isset($body['error'])){
            echo('<div class="notice notice-error">'.$body['error'].'</div>');
        }
        return $body;
    }
}
