<?php

use steps\WPshiftStep1;
use steps\WPshiftStep2;
use steps\WPshiftStep3;
use steps\WPshiftStep4;
use steps\WPshiftStep5;
use steps\WPshiftStep6;

class WPshiftWizard
{
    private static $steps = [
        WPshiftStep1::class,
        WPshiftStep2::class,
        WPshiftStep3::class,
        WPshiftStep4::class,
        WPshiftStep5::class,
        WPshiftStep6::class
    ];

    public static function init() {
        ob_start();
        add_action( 'admin_menu', [ __CLASS__, 'add_migration_page' ] );
        add_action( 'admin_enqueue_scripts', [ __CLASS__, 'enqueue_scripts' ] );
        session_start();
    }

    public static function add_migration_page() {
        add_submenu_page(
            'wpshift-dashboard',
            __( 'WPshift Migration', 'wpshift' ),
            __( 'WPshift Migration', 'wpshift' ),
            'manage_options',
            'wpshift-migration',
            [ __CLASS__, 'render_migration_page' ]
        );
    }

    public static function render_migration_page() {
        $current_step = isset( $_GET['step'] ) ? intval( $_GET['step'] ) : 1;
        $step_class = isset( self::$steps[$current_step - 1] ) ? self::$steps[$current_step - 1] : false;
        if ( ! $step_class || ! class_exists( $step_class ) ) {
            wp_die( __( 'Invalid step.', 'wpshift' ) );
        }

        $step_instance = new $step_class();

        if ( $_SERVER['REQUEST_METHOD'] === 'POST' ) {
            check_admin_referer( 'wpshift_migration_step_' . $current_step );
            $validation_result = $step_instance->validate();
            if ( $validation_result !== true ) {
                $_SESSION['wpshift_step_error'] = $validation_result;
            } else {
                $_SESSION['wpshift_step_' . $current_step] = $step_instance->save();
                unset($_SESSION['wpshift_step_error']);
                ob_end_clean();
                wp_safe_redirect( admin_url( 'admin.php?page=wpshift-migration&step=' . ( $current_step + 1 ) ) );
                exit;
            }
        }

        ?>
        <div class="wrap wpshift-dashboard">
            <div class="wpshift-dashboard-container">
                <div id="wpshift-loader" class="wpshift-loader-overlay">
                    <div class="wpshift-loader">
                        <div class="wpshift-spinner"></div>
                        <p>Loading, please wait...</p>
                    </div>
                </div>
                <img src="<?php echo esc_url( WPSHIFT_PLUGIN_URL . 'assets/images/logo.svg' ); ?>" alt="WPshift Logo" class="wpshift-logo">
                <h1 style="text-align: start"><?php _e( 'WPshift migration wizard', 'wpshift' ); ?></h1>
                <?php (new WPshiftWizard)->show_error(); ?>
                <form method="post" action="">
                    <?php wp_nonce_field( 'wpshift_migration_step_' . $current_step ); ?>

                    <?php $step_instance->layout(); ?>

                    <div class="submit-btn-container">
                        <?php if ( $current_step > 1 && $current_step != 6) : ?>
                            <a href="<?php echo esc_url( admin_url( 'admin.php?page=wpshift-migration&step=' . ( $current_step - 1 ) ) ); ?>" class="button button-primary button-secondary">
                                <?php _e( 'Back', 'wpshift' ); ?>
                            </a>
                        <?php endif; ?>
        <?php if ( $current_step != 6 ) : ?>

            <button type="submit" class="button button-primary button-hero">
                            <?php _e( 'Next', 'wpshift' ); ?>
                        </button>
        <?php endif; ?>

                    </div>
                </form>
            </div>
        </div>
        <?php
    }


    private function show_error() {
        if ( isset( $_SESSION['wpshift_step_error'] ) ) {
            ?>
            <div class="notice notice-error">
                <div><?php echo esc_html( $_SESSION['wpshift_step_error'] ); ?></div>
            </div>
            <?php
            // Remove the error message from the session after displaying it
            unset( $_SESSION['wpshift_step_error'] );
        }
    }

    public static function enqueue_scripts( $hook ) {
        if ( strpos( $hook, 'wpshift_page_wpshift-migration' ) === false ) {
            return;
        }

        wp_enqueue_style( 'wpshift-dashboard', WPSHIFT_PLUGIN_URL . 'assets/css/dashboard.css', [], WPSHIFT_VERSION );
        wp_enqueue_style( 'wpshift-wizard', WPSHIFT_PLUGIN_URL . 'assets/css/wizard.css', [], WPSHIFT_VERSION );

    }
}