<?php

namespace steps;

class WPshiftStep3
{
    public function layout() {
        $site_title = get_option('blogname');
        $site_url = $this->sanitize_domain(get_option('siteurl'));

        // Assume $domain_choices is an array of domains fetched from the API
        $domain_choices = \WPshiftApi::get_domains($_SESSION['wpshift_step_1']['wpshift_api_key']);

        ?>
        <style>
            .wpshift-form-container .wpshift-domain-section {
                display: none;
            }
            .wpshift-form-container .wpshift-domain-section.active {
                display: block;
            }
        </style>

        <div class="wpshift-form-container">
            <h2><?php _e( 'Step 3: Site Settings', 'wpshift' ); ?></h2>
            <p><?php _e( 'Please fill in the fields below.', 'wpshift' ); ?></p>

            <label class="block" for="wpshift_site_title"><?php _e('Site Title', 'wpshift'); ?></label>
            <input type="text" name="wpshift_site_title" id="wpshift_site_title" value="<?php echo esc_attr($site_title); ?>" class="input wpshift-input">

            <label class="block" for="wpshift_domain_option"><?php _e('Select Domain Option', 'wpshift'); ?></label>
            <select name="wpshift_domain_option" id="wpshift_domain_option" class="input wpshift-input">
                <option value="no_selected_option"><?php _e('Select a domain option', 'wpshift'); ?></option>
                <option value="wpshift_managed_domain"><?php _e('Domain managed in WPShift portal', 'wpshift'); ?></option>
                <option value="external_domain"><?php _e('External domain', 'wpshift'); ?></option>
                <option value="free_subdomain"><?php _e('Free subdomain', 'wpshift'); ?></option>
            </select>

            <div id="wpshift_managed_domain_section" class="wpshift-domain-section">
                <label class="block" for="wpshift_managed_domain_select"><?php _e('Select Your Domain', 'wpshift'); ?></label>
                <select name="wpshift_managed_domain_select" id="wpshift_managed_domain_select" class="wpshift-input">
                    <?php
                        foreach ($domain_choices as $domain) {
                            echo '<option value="' . esc_attr($domain) . '">' . esc_html($domain) . '</option>';
                        }
                    ?>
                </select>
            </div>

            <div id="external_domain_section" class="wpshift-domain-section">
                <label class="block" for="wpshift_external_domain"><?php _e('Enter Your Domain', 'wpshift'); ?></label>
                <input type="text" name="wpshift_external_domain" id="wpshift_external_domain" value="" class="wpshift-input">
            </div>

            <div id="free_subdomain_section" class="wpshift-domain-section">
                <label class="block" for="wpshift_free_subdomain"><?php _e('Create a free subdomain', 'wpshift'); ?></label>
                <div class="wpshift-subdomain">
                    <span>https://</span>
                    <input type="text" name="wpshift_free_subdomain" id="wpshift_free_subdomain" value="" class="wpshift-input">
                    <span>.wpshift.link</span>
                </div>
            </div>
        </div>

        <script type="text/javascript">
            (function($) {
                $(document).ready(function() {
                    function updateDomainSections() {
                        var selectedOption = $('#wpshift_domain_option').val();
                        $('.wpshift-domain-section').removeClass('active');

                        if (selectedOption === 'wpshift_managed_domain') {
                            $('#wpshift_managed_domain_section').addClass('active');
                        } else if (selectedOption === 'external_domain') {
                            $('#external_domain_section').addClass('active');
                        } else if (selectedOption === 'free_subdomain') {
                            $('#free_subdomain_section').addClass('active');
                        }
                    }
                    $('#wpshift_domain_option').change(updateDomainSections);
                    updateDomainSections(); // Initial call to set the correct state
                });
            })(jQuery);
        </script>

        <?php
    }

    private function sanitize_domain($url) {
        $host = parse_url($url, PHP_URL_HOST);

        return rtrim($host, '/');
    }

    public function validate() {
        if (empty($_POST['wpshift_site_title'])) {
            return __( 'The site title is required.', 'wpshift' );
        }

        if (empty($_POST['wpshift_domain_option']) || $_POST['wpshift_domain_option'] === 'no_selected_option') {
            return __( 'Please select a domain option.', 'wpshift' );
        }

        $domain_option = $_POST['wpshift_domain_option'];

        if ($domain_option === 'wpshift_managed_domain' && empty($_POST['wpshift_managed_domain_select'])) {
            return __( 'Please select a domain from the list.', 'wpshift' );
        } elseif ($domain_option === 'external_domain') {
            if (empty($_POST['wpshift_external_domain'])) {
                return __( 'Please enter your external domain.', 'wpshift' );
            }

            // Validate external domain
            $external_domain = sanitize_text_field($_POST['wpshift_external_domain']);
            if (!filter_var($external_domain, FILTER_VALIDATE_URL)) {
                return __( 'Please enter a valid URL for the external domain.', 'wpshift' );
            }
        } elseif ($domain_option === 'free_subdomain') {
            if (empty($_POST['wpshift_free_subdomain'])) {
                return __( 'Please enter your desired subdomain.', 'wpshift' );
            }

            // Validate subdomain using regex
            $subdomain = sanitize_text_field($_POST['wpshift_free_subdomain']);
            if (!preg_match('/^[a-z0-9]+(?:-[a-z0-9]+)*$/i', $subdomain)) {
                return __( 'Please enter a valid subdomain. Only letters, numbers, and hyphens are allowed.', 'wpshift' );
            }

            // Check if the subdomain is available
            $subdomain_check = \WPshiftApi::check_sub_domain($_SESSION['wpshift_step_1']['wpshift_api_key'], $subdomain);
            if (isset($subdomain_check['error'])) {
                return __( 'The subdomain is not available. Please choose a different one.', 'wpshift' );
            }
        }

        return true;
    }


    public function save() {
        $site_title = sanitize_text_field( $_POST['wpshift_site_title'] );
        $domain_option = sanitize_text_field( $_POST['wpshift_domain_option'] );

        $domain_value = '';
        if ($domain_option === 'wpshift_managed_domain') {
            $domain_value = sanitize_text_field( $_POST['wpshift_managed_domain_select'] );
        } elseif ($domain_option === 'external_domain') {
            $domain_value = sanitize_text_field( $_POST['wpshift_external_domain'] );
        } elseif ($domain_option === 'free_subdomain') {
            $domain_value = sanitize_text_field( $_POST['wpshift_free_subdomain'] );
        }

        return [
            'wpshift_site_title' => $site_title,
            'wpshift_domain_option' => $domain_option,
            'wpshift_domain_value' => $domain_value,
        ];
    }
}
