<?php

namespace steps;

use WPshiftBackup;

class WPshiftStep4
{
    public function layout() {
        ?>
        <h2><?php _e( 'Step 4: Backup Your Site', 'wpshift' ); ?></h2>
        <?php if (!$this->checkValidBackup()): ?>
        <p><?php _e( 'We are backing up your site files and database. This may take a while.', 'wpshift' ); ?></p>
        <?php endif; ?>
        <div id="backup-status"></div>
        <div id="progress-bar-container" style="display: none;">
            <div id="progress-bar" style="width: 0%; height: 20px; background-color: #4CAF50;"></div>
        </div>
        <?php if ($this->checkValidBackup()): ?>
        <div class="notice notice-info">We've discovered an old backup created with the WPShift plugin. Would you prefer to use this backup or generate a new one?</div>
            <button id="regenerate-backup" class="button button"><?php _e('Regenerate Backup', 'wpshift'); ?></button>
        <?php endif; ?>
        <script type="text/javascript">
            (function($) {
                function backupStep() {
                    $.post(ajaxurl, { action: 'wpshift_backup_step' }, function(response) {
                        if (response.status === 'done') {
                            $('#backup-status').html('<p>Backup completed!</p>');
                            $('#progress-bar').css('width', '100%');
                            $('#regenerate-backup').show(); // Show regenerate button after completion
                        } else if (response.status === 'partial') {
                            var progress = response.progress.toFixed(2);
                            $('#backup-status').html('<p>' + response.message + ' (' + progress + '% complete)</p>');
                            $('#progress-bar').css('width', progress + '%');
                            setTimeout(backupStep, 5000); // Wait 5 seconds before next call
                        } else {
                            $('#backup-status').html('<p>There was an error during the backup process. Please try again.</p>');
                        }
                    }, 'json').fail(function() {
                        $('#backup-status').html('<p>There was an error with the server request. Please try again.</p>');
                    });
                }

                $('#regenerate-backup').on('click', function(e) {
                    e.preventDefault();
                    $('#regenerate-backup').hide();
                    $('#backup-status').html('<p>Backup regeneration started. Please wait...</p>');
                    $('#progress-bar-container').show();
                    $('#progress-bar').css('width', '0%');
                    $.post(ajaxurl, { action: 'wpshift_regenerate_backup' }, function(response) {
                        backupStep(); // Start the backup process
                    });
                });

                if (!<?php echo json_encode($this->checkValidBackup()); ?>) {
                    $('#progress-bar-container').show();
                    backupStep(); // Start the initial backup process
                }
            })(jQuery);
        </script>
        <?php
    }

    public function validate() {

        if(!$this->checkValidBackup()){
            return __( 'Please wait for the backup to finish', 'wpshift' );

        }
    return true;
    }

    public function save() {
        // No data to save, just initiate the backup process
        return [];
    }

    private function checkValidBackup(){
        $backup = new WPshiftBackup();
        return $backup->is_backup_complete();
    }
}
