<?php

namespace steps;

use WPshiftBackup;

class WPshiftStep5
{
    public function layout() {
        // Retrieve the stored session data from previous steps
        $api_key = isset($_SESSION['wpshift_step_1']['wpshift_api_key']) ? $_SESSION['wpshift_step_1']['wpshift_api_key'] : '';
        $server_id = isset($_SESSION['wpshift_step_2']['wpshift_server_id']) ? $_SESSION['wpshift_step_2']['wpshift_server_id'] : '';
        $site_title = isset($_SESSION['wpshift_step_3']['wpshift_site_title']) ? $_SESSION['wpshift_step_3']['wpshift_site_title'] : '';
        $site_domain_type = isset($_SESSION['wpshift_step_3']['wpshift_domain_option']) ? $_SESSION['wpshift_step_3']['wpshift_domain_option'] : '';
        $site_domain = isset($_SESSION['wpshift_step_3']['wpshift_domain_value']) ? $_SESSION['wpshift_step_3']['wpshift_domain_value'] : '';

        // Sanitize the domain
        $site_domain = $this->sanitize_domain($site_domain);

        // Instantiate the backup class to get the backup file size
        $backup = new WPshiftBackup();

        ?>
        <h2><?php _e( 'Step 5: Confirm Your Settings', 'wpshift' ); ?></h2>
        <p><?php _e( 'Please review the following information before proceeding.', 'wpshift' ); ?></p>

        <table class="form-table">
            <tr>
                <th><?php _e( 'API Key', 'wpshift' ); ?></th>
                <td><?php echo esc_html($api_key); ?></td>
            </tr>
            <tr>
                <th><?php _e( 'Server ID', 'wpshift' ); ?></th>
                <td><?php echo esc_html($server_id); ?></td>
            </tr>
            <tr>
                <th><?php _e( 'Site Title', 'wpshift' ); ?></th>
                <td><?php echo esc_html($site_title); ?></td>
            </tr>
            <tr>
                <th><?php _e( 'Domain Type', 'wpshift' ); ?></th>
                <td><?php echo esc_html(str_replace('_', ' ', $site_domain_type)); ?></td>
            <tr>
                <th><?php _e( 'Site Domain', 'wpshift' ); ?></th>
                <td>
                    <?php
                    if($site_domain_type == 'free_subdomain') {
                        echo 'https://'. esc_html($site_domain) . '.wpshift.link';
                    }
                    if($site_domain_type == 'external_domain' || $site_domain_type == 'wpshift_managed_domain') {
                        echo esc_html($site_domain);
                    }
                    ?>
                </td>
            </tr>
            <tr>
                <th><?php _e( 'Backup File', 'wpshift' ); ?></th>
                <td><?php echo esc_html($backup->zip_file); ?></td>
            </tr>
        </table>

        <p><?php _e( 'When you click "Next", your site will be created in your workspace using the information above', 'wpshift' ); ?></p>
        <?php
    }

    private function sanitize_domain($domain) {
        $host = str_replace('http://', '', $domain);
        $host = str_replace('https://', '', $domain);

        return rtrim($host, '/');
    }

    public function validate() {
        // No validation needed for the confirmation step
        return true;
    }

    public function save() {
        // Sanitize the domain before using it
        $sanitized_domain = $this->sanitize_domain($_SESSION['wpshift_step_3']['wpshift_domain_value']);

        $backup = new WPshiftBackup();

        // Pass the sanitized domain to the API call
        $site = \WPshiftApi::create_site(
            $_SESSION['wpshift_step_1']['wpshift_api_key'],
            $_SESSION['wpshift_step_2']['wpshift_server_id'],
            $_SESSION['wpshift_step_3']['wpshift_site_title'],
            $sanitized_domain,
            $_SESSION['wpshift_step_3']['wpshift_domain_option'],
            $backup->zip_file,
        );
    }
}
