<?php
/**
 * Plugin Name: WPshift
 * Plugin URI: https://wpshift.io
 * Description: Our plugin helps you migrate WordPress sites to the WPshift platform effortlessly.
 * Version: 1.0.0
 * Author: The WPshift team
 * Author URI: https://wpshift.io
 * License: GPLv2 or later
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

// Define plugin constants.
define( 'WPSHIFT_VERSION', '1.0.0' );
define( 'WPSHIFT_PLUGIN_DIR', plugin_dir_path( __FILE__ ) );
define( 'WPSHIFT_PLUGIN_URL', plugin_dir_url( __FILE__ ) );

// Include required files.
require_once WPSHIFT_PLUGIN_DIR . 'includes/class-WPshiftApi.php';
require_once WPSHIFT_PLUGIN_DIR . 'includes/class-WPshiftDashboard.php';
require_once WPSHIFT_PLUGIN_DIR . 'includes/class-WPshiftSftp.php';
require_once WPSHIFT_PLUGIN_DIR . 'includes/class-WPshiftNotices.php';
require_once WPSHIFT_PLUGIN_DIR . 'includes/class-WPshiftWizard.php';
require_once WPSHIFT_PLUGIN_DIR . 'includes/class-WPshiftBackup.php';

require_once WPSHIFT_PLUGIN_DIR . 'includes/steps/class-WPshiftStep1.php';
require_once WPSHIFT_PLUGIN_DIR . 'includes/steps/class-WPshiftStep2.php';
require_once WPSHIFT_PLUGIN_DIR . 'includes/steps/class-WPshiftStep3.php';
require_once WPSHIFT_PLUGIN_DIR . 'includes/steps/class-WPshiftStep4.php';
require_once WPSHIFT_PLUGIN_DIR . 'includes/steps/class-WPshiftStep5.php';
require_once WPSHIFT_PLUGIN_DIR . 'includes/steps/class-WPshiftStep6.php';
function wpshift_init(): void
{
    WPshiftApi::init();
    WPshiftDashboard::init();
    WPshiftSftp::init();
    WPshiftNotices::init();
    WPshiftWizard::init();
}
add_action( 'plugins_loaded', 'wpshift_init' );

add_action('wp_ajax_wpshift_backup_step', function() {
    $backup = new WPshiftBackup();
    $result_files = $backup->backup_files();
    if ($result_files['status'] !== 'done') {
        echo json_encode($result_files);
        wp_die();
    }
    $result_db = $backup->backup_database();
    echo json_encode($result_db);

    wp_die();
});

add_action('wp_ajax_wpshift_regenerate_backup', function() {
    $backup = new WPshiftBackup();
    $backup->regenerate_backup();

    echo json_encode(['status' => 'regenerating']);
    wp_die();
});

function wpshift_activation_redirect() {
    set_transient( 'wpshift_activation_redirect', true, 30 );
}
register_activation_hook( __FILE__, 'wpshift_activation_redirect' );

add_action( 'admin_init', function() {
    if ( get_transient( 'wpshift_activation_redirect' ) && current_user_can( 'manage_options' ) ) {
        delete_transient( 'wpshift_activation_redirect' );
        wp_safe_redirect( admin_url( 'admin.php?page=wpshift-dashboard' ) );
        exit;
    }
});

